@@ -4,27 +4,26 @@ Copyright (C) 2013  Infobyte LLC (http://www.infobytesec.com/)
 See the file 'doc/LICENSE' for the license information
 
 """
+import hashlib
+import logging
 import os
+import re
 import shutil
 import tempfile
-
+import uuid
+import zipfile
 from collections import defaultdict
+from datetime import datetime
 
 import pytz
-import re
-import uuid
-import logging
 import simplejson as json
-import zipfile
-from datetime import datetime
-import hashlib
-
 
 logger = logging.getLogger("faraday").getChild(__name__)
 
 VALID_SERVICE_STATUS = ("open", "closed", "filtered")
 VULN_SKIP_FIELDS_TO_HASH = ['run_date']
 
+
 class PluginBase:
     # TODO: Add class generic identifier
     class_signature = "PluginBase"
@@ -41,6 +40,7 @@ class PluginBase:
         self.name = None
         self.description = ""
         self._command_regex = None
+        self.command = None
         self._output_file_path = None
         self._use_temp_file = False
         self._delete_temp_file = False
@@ -102,6 +102,7 @@ class PluginBase:
                 if severity[0:3] in sev:
                     return sev
             return severity
+
         severity = align_string_based_vulns(severity)
         # Transform numeric severity into desc severity
         numeric_severities = {"0": "info",
@@ -125,6 +126,9 @@ class PluginBase:
             self._hosts_cache[cache_id] = obj_uuid
         else:
             obj_uuid = self._hosts_cache[cache_id]
+            if host['hostnames']:
+                chached_host = self.get_from_cache(obj_uuid)
+                chached_host['hostnames'] = list(set(chached_host['hostnames'] + host['hostnames']))
         return obj_uuid
 
     def save_service_cache(self, host_id, service):
@@ -170,7 +174,6 @@ class PluginBase:
     def _get_dict_hash(d, keys):
         return hash(frozenset(map(lambda x: (x, d.get(x, None)), keys)))
 
-
     @classmethod
     def get_host_cache_id(cls, host):
         cache_id = cls._get_dict_hash(host, ['ip'])
@@ -187,14 +190,17 @@ class PluginBase:
     def get_service_vuln_cache_id(cls, host_id, service_id, vuln):
         vuln_copy = vuln.copy()
         vuln_copy.update({"host_cache_id": host_id, "service_cache_id": service_id})
-        cache_id = cls._get_dict_hash(vuln_copy, ['host_cache_id', 'service_cache_id', 'name', 'desc', 'website', 'path', 'pname', 'method'])
+        cache_id = cls._get_dict_hash(vuln_copy,
+                                      ['host_cache_id', 'service_cache_id', 'name', 'desc', 'website', 'path', 'pname',
+                                       'method'])
         return cache_id
 
     @classmethod
     def get_host_vuln_cache_id(cls, host_id, vuln):
         vuln_copy = vuln.copy()
         vuln_copy.update({"host_cache_id": host_id})
-        cache_id = cls._get_dict_hash(vuln_copy, ['host_cache_id', 'name', 'desc', 'website', 'path', 'pname', 'method'])
+        cache_id = cls._get_dict_hash(vuln_copy,
+                                      ['host_cache_id', 'name', 'desc', 'website', 'path', 'pname', 'method'])
         return cache_id
 
     def save_cache(self, obj):
@@ -228,7 +234,7 @@ class PluginBase:
         for param, (param_type, value) in self._settings.items():
             yield param, value
 
-    def get_ws(self): # TODO Borrar
+    def get_ws(self):  # TODO Borrar
         return ""
 
     def getSetting(self, name):
@@ -249,8 +255,17 @@ class PluginBase:
         This method can be overriden in the plugin implementation
         if a different kind of check is needed
         """
-        return (self._command_regex is not None and
-                self._command_regex.match(current_input.strip()) is not None)
+        if (self._command_regex is not None and
+                self._command_regex.match(current_input.strip()) is not None):
+            self.command = self.get_command(current_input)
+            return True
+
+    def get_command(self, current_input: str) -> str:
+        command = self._command_regex.findall(current_input)[0]
+        if isinstance(command, tuple):
+            return "".join(command).strip()
+
+        return command.strip()
 
     def processCommandString(self, username, current_path, command_string):
         """
@@ -334,15 +349,15 @@ class PluginBase:
             tags = []
         if isinstance(tags, str):
             tags = [tags]
-        host = {"ip": name, "os": os, "hostnames": hostnames, "description": description,  "mac": mac,
+        host = {"ip": name, "os": os, "hostnames": hostnames, "description": description, "mac": mac,
                 "credentials": [], "services": [], "vulnerabilities": [], "tags": tags}
         host_id = self.save_host_cache(host)
         return host_id
 
     def createAndAddServiceToHost(self, host_id, name,
-                                       protocol="tcp", ports=None,
-                                       status="open", version="unknown",
-                                       description="", tags=None):
+                                  protocol="tcp", ports=None,
+                                  status="open", version="",
+                                  description="", tags=None):
         if ports:
             if isinstance(ports, list):
                 ports = int(ports[0])
@@ -412,7 +427,8 @@ class PluginBase:
             tags = [tags]
         vulnerability = {"name": name, "desc": desc, "severity": self.normalize_severity(severity), "refs": ref,
                          "external_id": external_id, "type": "Vulnerability", "resolution": resolution, "data": data,
-                         "custom_fields": custom_fields, "status": status, "impact": impact, "policyviolations": policyviolations,
+                         "custom_fields": custom_fields, "status": status, "impact": impact,
+                         "policyviolations": policyviolations,
                          "easeofresolution": easeofresolution, "confirmed": confirmed, "tags": tags
                          }
         if run_date:
@@ -426,7 +442,8 @@ class PluginBase:
                                      response="", method="", pname="",
                                      params="", query="", category="", data="", external_id=None,
                                      confirmed=False, status="", easeofresolution=None, impact=None,
-                                     policyviolations=None, status_code=None, custom_fields=None, run_date=None, tags=None):
+                                     policyviolations=None, status_code=None, custom_fields=None, run_date=None,
+                                     tags=None):
         if params is None:
             params = ""
         if response is None:
@@ -476,7 +493,6 @@ class PluginBase:
     def createAndAddNoteToHost(self, host_id, name, text):
         return None
 
-
     def createAndAddNoteToService(self, host_id, service_id, name, text):
         return None
 
@@ -492,7 +508,7 @@ class PluginBase:
 
     def get_data(self):
         self.vulns_data["command"]["tool"] = self.id
-        self.vulns_data["command"]["command"] = self.id
+        self.vulns_data["command"]["command"] = self.command if self.command else self.id
         self.vulns_data["command"]["duration"] = (datetime.now() - self.start_date).microseconds
         return self.vulns_data
 
@@ -529,6 +545,7 @@ class PluginBase:
             summary['vuln_hashes'].append(dict_hash)
         return summary
 
+
 # TODO Borrar
 class PluginTerminalOutput(PluginBase):
     def __init__(self):
@@ -667,5 +684,3 @@ class PluginZipFormat(PluginByExtension):
             match = bool(self.files_list & files_in_zip)
             self.logger.debug("Files List Match: [%s =/in %s] -> %s", files_in_zip, self.files_list, match)
         return match
-
-
