@@ -22,8 +22,8 @@ class CmdArpScanPlugin(PluginBase):
     Basically inserts into the tree the ouput of this tool
     """
 
-    def __init__(self):
-        super().__init__()
+    def __init__(self, *arg, **kwargs):
+        super().__init__(*arg, **kwargs)
         self.id = "arp-scan"
         self.name = "arp-scan network scanner"
         self.plugin_version = "0.0.2"
@@ -54,13 +54,12 @@ class CmdArpScanPlugin(PluginBase):
                     if len(vals[0].split(".")) == 4:
 
                         host = vals[0]
-                        h_id = self.createAndAddHost(host)
-                        i_id = self.createAndAddInterface(h_id, host, ipv4_address=host, mac=vals[1])
+                        h_id = self.createAndAddHost(host, mac=vals[1])
 
         return True
 
 
 
-def createPlugin():
-    return CmdArpScanPlugin()
+def createPlugin(ignore_info=False):
+    return CmdArpScanPlugin(ignore_info=ignore_info)
 
